<p align="center">
  <picture>
    <source media="(prefers-color-scheme: dark)" srcset="assets/logo-dark.svg">
    <source media="(prefers-color-scheme: light)" srcset="assets/logo-light.svg">
    <img alt="ZooCache Logo" src="assets/logo-light.svg" width="600">
  </picture>
</p>

{% include-markdown "../README.md" start="</p>" %}
